"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.breakpoints = exports.between = exports.until = exports.from = void 0;
const index_1 = require("../index");
Object.defineProperty(exports, "breakpoints", { enumerable: true, get: function () { return index_1.breakpoints; } });
const minWidth = (from) => `@media (min-width: ${`${from}px`})`;
const maxWidth = (until) => `@media (max-width: ${`${until - 1}px`})`;
const minWidthMaxWidth = (from, until) => `@media (min-width: ${`${from}px`}) and (max-width: ${`${until - 1}px`})`;
// e.g. from.*
const from = {
    mobile: minWidth(index_1.breakpoints.mobile),
    mobileMedium: minWidth(index_1.breakpoints.mobileMedium),
    mobileLandscape: minWidth(index_1.breakpoints.mobileLandscape),
    phablet: minWidth(index_1.breakpoints.phablet),
    tablet: minWidth(index_1.breakpoints.tablet),
    desktop: minWidth(index_1.breakpoints.desktop),
    leftCol: minWidth(index_1.breakpoints.leftCol),
    wide: minWidth(index_1.breakpoints.wide),
};
exports.from = from;
// e.g. until.*
const until = {
    mobile: maxWidth(index_1.breakpoints.mobile),
    mobileMedium: maxWidth(index_1.breakpoints.mobileMedium),
    mobileLandscape: maxWidth(index_1.breakpoints.mobileLandscape),
    phablet: maxWidth(index_1.breakpoints.phablet),
    tablet: maxWidth(index_1.breakpoints.tablet),
    desktop: maxWidth(index_1.breakpoints.desktop),
    leftCol: maxWidth(index_1.breakpoints.leftCol),
    wide: maxWidth(index_1.breakpoints.wide),
};
exports.until = until;
// e.g. between.*.and.*
const between = {
    mobile: {
        and: {
            mobileMedium: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.mobileMedium),
            mobileLandscape: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(index_1.breakpoints.mobile, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.wide),
        },
    },
    mobileMedium: {
        and: {
            mobileLandscape: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.mobileMedium, index_1.breakpoints.wide),
        },
    },
    mobileLandscape: {
        and: {
            phablet: minWidthMaxWidth(index_1.breakpoints.mobileLandscape, index_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(index_1.breakpoints.mobileLandscape, index_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(index_1.breakpoints.mobileLandscape, index_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(index_1.breakpoints.mobileLandscape, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.mobileLandscape, index_1.breakpoints.wide),
        },
    },
    phablet: {
        and: {
            tablet: minWidthMaxWidth(index_1.breakpoints.phablet, index_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(index_1.breakpoints.phablet, index_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(index_1.breakpoints.phablet, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.phablet, index_1.breakpoints.wide),
        },
    },
    tablet: {
        and: {
            desktop: minWidthMaxWidth(index_1.breakpoints.tablet, index_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(index_1.breakpoints.tablet, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.tablet, index_1.breakpoints.wide),
        },
    },
    desktop: {
        and: {
            leftCol: minWidthMaxWidth(index_1.breakpoints.desktop, index_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(index_1.breakpoints.desktop, index_1.breakpoints.wide),
        },
    },
    leftCol: {
        and: {
            wide: minWidthMaxWidth(index_1.breakpoints.leftCol, index_1.breakpoints.wide),
        },
    },
};
exports.between = between;
//# sourceMappingURL=index.js.map