"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fs = void 0;
const data_1 = require("./data");
function getFontStyle(font, fontStyle) {
    switch (fontStyle) {
        case 'italic':
            return font && font.hasItalic ? 'italic' : null;
        case 'normal':
            return 'normal';
        case null:
        default:
            return null;
    }
}
const fs = (category) => (level, { lineHeight, fontWeight, fontStyle, unit }) => {
    const fontFamilyValue = data_1.fontMapping[category];
    const fontSizeValue = unit === 'px'
        ? data_1.fontSizeMapping[category][level]
        : `${data_1.remFontSizeMapping[category][level]}rem`;
    const lineHeightValue = unit === 'px'
        ? // line-height is defined as a unitless value, so we multiply
            // by the element's font-size in px to get the px value
            `${data_1.lineHeightMapping[lineHeight] *
                data_1.fontSizeMapping[category][level]}px`
        : data_1.lineHeightMapping[lineHeight];
    // TODO: consider logging an error in development if a requested
    // font is unavailable
    const requestedFont = data_1.availableFonts[category][fontWeight];
    const fontWeightValue = requestedFont ? data_1.fontWeightMapping[fontWeight] : '';
    const fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
        fontFamily: fontFamilyValue,
        fontSize: fontSizeValue,
        lineHeight: lineHeightValue,
    }, fontWeightValue ? { fontWeight: fontWeightValue } : {}, fontStyleValue ? { fontStyle: fontStyleValue } : {});
};
exports.fs = fs;
//# sourceMappingURL=fs.js.map